==> ui-0.2.43.tgz: package/lib/cjs/MultiSelect/selectItem/index.js <==
"use strict";

var _WeakMap = require("@babel/runtime-corejs3/core-js-stable/weak-map");
var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
var _Object$getOwnPropertyDescriptor = require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-descriptor");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _assign = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/assign"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _react = require("react");
var Styled = _interopRequireWildcard(require("../MultiSelect.styled"));
var _MultiSelect2 = require("../MultiSelect.constants");
var _defaultItem = _interopRequireDefault(require("../defaultItem"));
var _hooks = require("../../@hooks");
function _getRequireWildcardCache(nodeInterop) { if (typeof _WeakMap !== "function") return null; var cacheBabelInterop = new _WeakMap(); var cacheNodeInterop = new _WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = _Object$defineProperty && _Object$getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? _Object$getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { _Object$defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
/**
 * This component represents an individual item in the multi-select drop-down
 */

const SelectItem = _ref => {
  let {
    itemRenderer: ItemRenderer = _defaultItem.default,
    option,
    checked,
    tabIndex,
    disabled,
    onSelectionChanged,
    onClick,
    isCheckboxShowing
  } = _ref;
  const itemRef = (0, _react.useRef)();
  const onOptionCheck = e => {
    toggleChecked();
    e.preventDefault();
  };
  const toggleChecked = () => {
    if (!disabled) {
      onSelectionChanged(!checked);
    }
  };
  const handleClick = e => {
    toggleChecked();
    onClick(e);
  };
  (0, _hooks.useKey)([_MultiSelect2.KEY.ENTER, _MultiSelect2.KEY.SPACE], onOptionCheck, {
    target: itemRef
  });
  return (0, _jsxRuntime.jsx)(Styled.SelectItemWrapper, (0, _assign.default)({
    "$selected": !!checked,
    role: "option",
    "aria-selected": checked,
    tabIndex: tabIndex,
    ref: itemRef
  }, {
    children: (0, _jsxRuntime.jsx)(ItemRenderer, {
      option: option,
      checked: checked,
      onClick: handleClick,
      disabled: disabled,
      isCheckboxShowing: isCheckboxShowing
    })
  }));
};
var _default = SelectItem;
exports.default = _default;

==> ui-0.2.52.tgz: package/lib/cjs/MultiSelect/selectItem/index.js <==
"use strict";

var _WeakMap = require("@babel/runtime-corejs3/core-js-stable/weak-map");
var _Object$defineProperty = require("@babel/runtime-corejs3/core-js-stable/object/define-property");
var _Object$getOwnPropertyDescriptor = require("@babel/runtime-corejs3/core-js-stable/object/get-own-property-descriptor");
var _interopRequireDefault = require("@babel/runtime-corejs3/helpers/interopRequireDefault");
_Object$defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _assign = _interopRequireDefault(require("@babel/runtime-corejs3/core-js-stable/object/assign"));
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _react = require("react");
var Styled = _interopRequireWildcard(require("../MultiSelect.styled"));
var _MultiSelect2 = require("../MultiSelect.constants");
var _defaultItem = _interopRequireDefault(require("../defaultItem"));
var _hooks = require("../../@hooks");
function _getRequireWildcardCache(e) { if ("function" != typeof _WeakMap) return null; var r = new _WeakMap(), t = new _WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = _Object$defineProperty && _Object$getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && Object.prototype.hasOwnProperty.call(e, u)) { var i = a ? _Object$getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? _Object$defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * This component represents an individual item in the multi-select drop-down
 */

const SelectItem = _ref => {
  let {
    itemRenderer: ItemRenderer = _defaultItem.default,
    option,
    checked,
    tabIndex,
    disabled,
    onSelectionChanged,
    onClick,
    isCheckboxShowing
  } = _ref;
  const itemRef = (0, _react.useRef)();
  const onOptionCheck = e => {
    toggleChecked();
    e.preventDefault();
  };
  const toggleChecked = () => {
    if (!disabled) {
      onSelectionChanged(!checked);
    }
  };
  const handleClick = e => {
    toggleChecked();
    onClick(e);
  };
  (0, _hooks.useKey)([_MultiSelect2.KEY.ENTER, _MultiSelect2.KEY.SPACE], onOptionCheck, {
    target: itemRef
  });
  return (0, _jsxRuntime.jsx)(Styled.SelectItemWrapper, (0, _assign.default)({
    "$selected": !!checked,
    role: "option",
    "aria-selected": checked,
    tabIndex: tabIndex,
    ref: itemRef
  }, {
    children: (0, _jsxRuntime.jsx)(ItemRenderer, {
      option: option,
      checked: checked,
      onClick: handleClick,
      disabled: disabled,
      isCheckboxShowing: isCheckboxShowing
    })
  }));
};
var _default = exports.default = SelectItem;
